Learn R Programming

rnaSeqMap (version 2.30.0)

gRanges2CamelMeasures: Genomic plots based upon NucleotideDistr objects

Description

Various plots of genomic coverage for data from NucleotideDistr objects

Usage

gRanges2CamelMeasures(gR, cvd, sample.idx1, sample.idx2, sums=NULL, progress=NULL) allCamelMeasuresForRegion(ch, st, en, str, cvd, sample.idx1, sample.idx2, sums=NULL)

Arguments

ch
chromosome name
st
genomic start
en
genomic end
str
strand
cvd
name of the file with BAM description - covdesc
gR
GenomicRanges object to use as a set of genomic regions to query
sample.idx1,sample.idx2
sample indices
sums
the vector of sums for normalization
progress
every how many regions print a dot for progress indicator

Examples

Run this code
# 
  

Run the code above in your browser using DataLab